@@ -208,11 +208,11 @@ parser_mRNA.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_mRNA.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_mRNA.add_argument('-t', '--transcript', type=str, 
+parser_mRNA.add_argument('-i', '--transcript', type=str, 
                          help='specific transcript; if not given, return whole transcripts')
 parser_mRNA.add_argument('-o', '--output', type=str, 
                          help = 'output file path')
-parser_mRNA.add_argument('--output_format', type=str, choices=['csv','fasta'], 
+parser_mRNA.add_argument('-t', '--output_format', type=str, choices=['csv','fasta'], 
                          help = 'output format')
 parser_mRNA.add_argument('-p', '--print', action="store_true", 
                          help='output to stdout')
@@ -229,11 +229,11 @@ parser_cdna.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_cdna.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_cdna.add_argument('-t', '--transcript', type=str, 
+parser_cdna.add_argument('-i', '--transcript', type=str, 
                          help='specific transcript; if not given, return whole transcripts')
 parser_cdna.add_argument('-o', '--output', type=str, 
                          help = 'output file path')
-parser_cdna.add_argument('--output_format', type=str, choices=['csv','fasta'], 
+parser_cdna.add_argument('-t', '--output_format', type=str, choices=['csv','fasta'], 
                          help = 'output format')
 parser_cdna.add_argument('-p', '--print', action="store_true", 
                          help='output to stdout')
@@ -267,7 +267,7 @@ parser_utr.add_argument('-d', '--database', type=str, required=True,
                         help='database generated by subcommand create')
 parser_utr.add_argument('-f', '--genome', type=str, required=True,
                         help='genome fasta file')
-parser_utr.add_argument('-t', '--transcript', type=str, 
+parser_utr.add_argument('-i', '--transcript', type=str, 
                         help='specific transcript id; if not given, \
                         whole transcript will return')
 parser_utr.add_argument('-o', '--output', type=str, 
@@ -284,9 +284,11 @@ parser_uORF.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_uORF.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_uORF.add_argument('-t', '--transcript', type=str, 
+parser_uORF.add_argument('-i', '--transcript', type=str, 
                          help='specific transcript id; if not given, \
                                whole transcript will return')
+parser_uORF.add_argument('-t', '--output_format', choices=['csv','fasta','gff'], 
+                        help='output format ')
 parser_uORF.add_argument('-o', '--output', type=str, 
                          help='output file path')
 parser_uORF.add_argument('-s', '--style', choices=['GFF','GTF'], 
@@ -299,13 +301,15 @@ parser_cds.add_argument('-d', '--database', type=str, required=True,
                         help='database generated by subcommand create')
 parser_cds.add_argument('-f', '--genome', type=str, required=True,
                         help='genome fasta')
-parser_cds.add_argument('-t', '--transcript', type=str, 
+parser_cds.add_argument('-i', '--transcript', type=str, 
                         help='specific transcript id; if not given, \
                         whole transcript will return')
 parser_cds.add_argument('-o', '--output', type=str, 
                         help='output file path')
 parser_cds.add_argument('-p', '--print', action="store_true", 
                         help='output to stdout')
+parser_cds.add_argument('-t', '--output_format', type=str, choices=['csv','fasta'],
+                         help = 'output format')
 parser_cds.add_argument('-s', '--style', choices=['GFF','GTF'], 
                         help = 'GTF database or GFF database')
 parser_cds.set_defaults(func=CDS)
@@ -316,9 +320,11 @@ parser_dORF.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_dORF.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_dORF.add_argument('-t', '--transcript', type=str, 
+parser_dORF.add_argument('-i', '--transcript', type=str, 
                          help='specific transcript id; if not given, \
                                whole transcript will return')
+parser_dORF.add_argument('-t', '--output_format', choices=['csv','fasta','gff'],
+                        help='output format ')
 parser_dORF.add_argument('-o', '--output', type=str, 
                          help='output file path')
 parser_dORF.add_argument('-p', '--print', action="store_true", 
@@ -334,7 +340,7 @@ parser_exon.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_exon.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_exon.add_argument('-t', '--transcript', type=str, 
+parser_exon.add_argument('-i', '--transcript', type=str, 
                          help='specific transcript id; needed')
 parser_exon.add_argument('-o', '--output', type=str, 
                          help='output file path')
@@ -350,7 +356,7 @@ parser_intron.add_argument('-d', '--database', type=str, required=True,
                            help='database generated by subcommand create')
 parser_intron.add_argument('-f', '--genome', type=str, required=True, 
                            help='genome fasta')
-parser_intron.add_argument('-t', '--transcript', type=str, 
+parser_intron.add_argument('-i', '--transcript', type=str, 
                            help='specific transcript id; needed')
 parser_intron.add_argument('-o', '--output', type=str, 
                            help='output file path')
